@@ -10,6 +10,7 @@ from dagster.core.storage.pipeline_run import PipelineRunStatus
 from dagster.core.test_utils import poll_for_finished_run, poll_for_step_start
 from dagster.utils.test.postgres_instance import postgres_instance_for_test
 from dagster.utils.yaml_utils import merge_yamls
+from dagster_docker.docker_run_launcher import DOCKER_IMAGE_TAG
 from dagster_test.test_project import (
     ReOriginatedExternalPipelineForTest,
     find_local_test_image,
@@ -37,7 +38,10 @@ def test_launch_docker_image_on_pipeline_config():
 
     docker_image = get_test_project_docker_image()
     launcher_config = {
-        "env_vars": ["AWS_ACCESS_KEY_ID", "AWS_SECRET_ACCESS_KEY",],
+        "env_vars": [
+            "AWS_ACCESS_KEY_ID",
+            "AWS_SECRET_ACCESS_KEY",
+        ],
         "network": "container:test-postgres-db-docker",
     }
 
@@ -64,7 +68,8 @@ def test_launch_docker_image_on_pipeline_config():
     ) as instance:
         recon_pipeline = get_test_project_recon_pipeline("demo_pipeline", docker_image)
         run = instance.create_run_for_pipeline(
-            pipeline_def=recon_pipeline.get_definition(), run_config=run_config,
+            pipeline_def=recon_pipeline.get_definition(),
+            run_config=run_config,
         )
 
         external_pipeline = ReOriginatedExternalPipelineForTest(
@@ -75,7 +80,11 @@ def test_launch_docker_image_on_pipeline_config():
 
         poll_for_finished_run(instance, run.run_id, timeout=60)
 
-        assert instance.get_run_by_id(run.run_id).status == PipelineRunStatus.SUCCESS
+        run = instance.get_run_by_id(run.run_id)
+
+        assert run.status == PipelineRunStatus.SUCCESS
+
+        assert run.tags[DOCKER_IMAGE_TAG] == docker_image
 
 
 def _check_event_log_contains(event_log, expected_type_and_message):
@@ -93,7 +102,10 @@ def _check_event_log_contains(event_log, expected_type_and_message):
 def test_terminate_launched_docker_run():
     docker_image = get_test_project_docker_image()
     launcher_config = {
-        "env_vars": ["AWS_ACCESS_KEY_ID", "AWS_SECRET_ACCESS_KEY",],
+        "env_vars": [
+            "AWS_ACCESS_KEY_ID",
+            "AWS_SECRET_ACCESS_KEY",
+        ],
         "network": "container:test-postgres-db-docker",
     }
 
@@ -102,7 +114,11 @@ def test_terminate_launched_docker_run():
     else:
         find_local_test_image(docker_image)
 
-    run_config = merge_yamls([os.path.join(get_test_project_environments_path(), "env_s3.yaml"),])
+    run_config = merge_yamls(
+        [
+            os.path.join(get_test_project_environments_path(), "env_s3.yaml"),
+        ]
+    )
 
     with docker_postgres_instance(
         overrides={
@@ -115,7 +131,8 @@ def test_terminate_launched_docker_run():
     ) as instance:
         recon_pipeline = get_test_project_recon_pipeline("hanging_pipeline", docker_image)
         run = instance.create_run_for_pipeline(
-            pipeline_def=recon_pipeline.get_definition(), run_config=run_config,
+            pipeline_def=recon_pipeline.get_definition(),
+            run_config=run_config,
         )
 
         run_id = run.run_id
@@ -152,7 +169,10 @@ def test_terminate_launched_docker_run():
 def test_launch_docker_invalid_image():
     docker_image = "_invalid_format_image"
     launcher_config = {
-        "env_vars": ["AWS_ACCESS_KEY_ID", "AWS_SECRET_ACCESS_KEY",],
+        "env_vars": [
+            "AWS_ACCESS_KEY_ID",
+            "AWS_SECRET_ACCESS_KEY",
+        ],
         "network": "container:test-postgres-db-docker",
         "image": docker_image,
     }
@@ -178,7 +198,8 @@ def test_launch_docker_invalid_image():
     ) as instance:
         recon_pipeline = get_test_project_recon_pipeline("demo_pipeline")
         run = instance.create_run_for_pipeline(
-            pipeline_def=recon_pipeline.get_definition(), run_config=run_config,
+            pipeline_def=recon_pipeline.get_definition(),
+            run_config=run_config,
         )
 
         external_pipeline = ReOriginatedExternalPipelineForTest(
@@ -194,7 +215,10 @@ def test_launch_docker_invalid_image():
 def test_launch_docker_image_on_instance_config():
     docker_image = get_test_project_docker_image()
     launcher_config = {
-        "env_vars": ["AWS_ACCESS_KEY_ID", "AWS_SECRET_ACCESS_KEY",],
+        "env_vars": [
+            "AWS_ACCESS_KEY_ID",
+            "AWS_SECRET_ACCESS_KEY",
+        ],
         "network": "container:test-postgres-db-docker",
         "image": docker_image,
     }
@@ -222,7 +246,8 @@ def test_launch_docker_image_on_instance_config():
     ) as instance:
         recon_pipeline = get_test_project_recon_pipeline("demo_pipeline")
         run = instance.create_run_for_pipeline(
-            pipeline_def=recon_pipeline.get_definition(), run_config=run_config,
+            pipeline_def=recon_pipeline.get_definition(),
+            run_config=run_config,
         )
 
         external_pipeline = ReOriginatedExternalPipelineForTest(
